@@ -58,7 +58,7 @@ class Task(BaseIserv):
 
         self.author = None
         self.description = None
-        self.provided_files = {}
+        self.provided_files = []
 
     def get_details(self, path="/iserv/exercise/show/"):
         self._login()
